@@ -11,13 +11,16 @@ def decode(value):
 # http://stackoverflow.com/questions/4698220/django-template-convert-python-list-into-a-javascript-object    
 from django.core.serializers import serialize
 from django.db.models.query import QuerySet
-from django.utils import simplejson
+try:
+    from django.utils import simplejson as json
+except:
+    import json
 from django.utils.safestring import mark_safe
 
 def jsonify(object):
     if isinstance(object, QuerySet):
         return mark_safe(serialize('json', object))
-    return mark_safe(simplejson.dumps(object))
+    return mark_safe(json.dumps(object))
 
 register.filter('jsonify', jsonify)
-jsonify.is_safe = True  
\ No newline at end of file
+jsonify.is_safe = True  
